@@ -5,13 +5,16 @@ This module contains all functions, necessary for the inititation of an emipy pr
 
 import pandas as pd
 import os
-from os.path import join, isfile
-import matplotlib.pyplot as plt
-import requests, zipfile, io
-import csv
+
+import requests
+import zipfile
+import io
+
 import configparser
 import urllib.request
 
+path_sep = os.sep
+
 
 def download_PollutionData(path, chunk_size=128):
     """
@@ -34,7 +37,10 @@ def download_PollutionData(path, chunk_size=128):
     if os.path.isdir(path) is False:
         os.mkdir(path)
     if not os.listdir(path):
-        url = 'https://www.eea.europa.eu/data-and-maps/data/member-states-reporting-art-7-under-the-european-pollutant-release-and-transfer-register-e-prtr-regulation-23/european-pollutant-release-and-transfer-register-e-prtr-data-base/eprtr_v9_csv.zip/at_download/file'
+        url = ('https://www.eea.europa.eu/data-and-maps/data/' +
+               'member-states-reporting-art-7-under-the-european-pollutant' +
+               '-release-and-transfer-register-e-prtr-regulation-23/european-' +
+               'pollutant-release-and-transfer-register-e-prtr-data-base/eprtr_v9_csv.zip/at_download/file')
         r = requests.get(url, stream=True)
         z = zipfile.ZipFile(io.BytesIO(r.content))
         z.extractall(path)
@@ -68,7 +74,7 @@ def download_MapData(path, resolution=10, clear=False, chunk_size=128):
         if os.path.isdir(path) is False:
             os.mkdir(path)
 
-        if clear == True:
+        if clear:
             os.chdir(path)
             for item in os.listdir(path):
                 file_name = os.path.abspath(item)
@@ -129,7 +135,7 @@ def download_MapData(path, resolution=10, clear=False, chunk_size=128):
                 urllist.append(urldict.get(urlkey))
 
         for items in urllist:
-            if items == None:
+            if items is None:
                 continue
             r = requests.get(items, stream=True)
             z = zipfile.ZipFile(io.BytesIO(r.content))
@@ -166,8 +172,10 @@ def download_NACE_TransitionTables(path):
     if os.path.isdir(path) is False:
         os.mkdir(path)
     if not os.listdir(path):
-        url1 = r'https://ec.europa.eu/eurostat/documents/1965800/1978760/52249E90762B69F8E0440003BA9322F9.xls/2314229f-7606-4230-96d4-da18f045b692'
-        url2 = r'https://ec.europa.eu/eurostat/documents/1965800/1978760/Copy+of+5225C5EEBF016050E0440003BA9322F9.xls/6e1aec88-f15b-4d0f-bccc-4ee505c7f810'
+        url1 = (r'https://ec.europa.eu/eurostat/documents/1965800/1978760/' +
+                '52249E90762B69F8E0440003BA9322F9.xls/2314229f-7606-4230-96d4-da18f045b692')
+        url2 = (r'https://ec.europa.eu/eurostat/documents/1965800/1978760/' +
+                'Copy+of+5225C5EEBF016050E0440003BA9322F9.xls/6e1aec88-f15b-4d0f-bccc-4ee505c7f810')
         urllib.request.urlretrieve(url1, os.path.join(path, 'Correspondance+table+NACERev2-NACERev1_1+table+format.xls'))
         urllib.request.urlretrieve(url2, os.path.join(path, 'Correspondance+table+NACERev1_1-NACERev2+table+format.xls'))
 
@@ -188,20 +196,21 @@ def pickle_RawData(path, force_rerun=False):
     None.
 
     """
+
     # POLLUTANTRELEASEANDTRANSFERREPORT
-    if ((os.path.isfile(os.path.join(path, 'PollutionData\\pratr.pkl')) is False) or force_rerun):
-        pratr = pd.read_csv(os.path.join(path, 'PollutionData\\dbo.PUBLISH_POLLUTANTRELEASEANDTRANSFERREPORT.csv'))
-        pratr.to_pickle(os.path.join(path, 'PollutionData\\pratr.pkl'))
+    if (os.path.isfile(os.path.join(path, 'PollutionData', 'pratr.pkl')) is False) or force_rerun:
+        pratr = pd.read_csv(os.path.join(path, 'PollutionData', 'dbo.PUBLISH_POLLUTANTRELEASEANDTRANSFERREPORT.csv'))
+        pratr.to_pickle(os.path.join(path, 'PollutionData', 'pratr.pkl'))
 
     # FACILITYREPORT
-    if ((os.path.isfile(os.path.join(path, 'PollutionData\\fr.pkl')) is False) or force_rerun):
-        fr = pd.read_csv(os.path.join(path, 'PollutionData\\dbo.PUBLISH_FACILITYREPORT.csv'), encoding='latin-1', low_memory=False)
-        fr.to_pickle(os.path.join(path, 'PollutionData\\fr.pkl'))
+    if (os.path.isfile(os.path.join(path, 'PollutionData', 'fr.pkl')) is False) or force_rerun:
+        fr = pd.read_csv(os.path.join(path, 'PollutionData', 'dbo.PUBLISH_FACILITYREPORT.csv'), encoding='latin-1', low_memory=False)
+        fr.to_pickle(os.path.join(path, 'PollutionData', 'fr.pkl'))
 
     # POLLUTANTRELEASE
-    if ((os.path.isfile(os.path.join(path, 'PollutionData\\pr.pkl')) is False) or force_rerun):
-        pr = pd.read_csv(os.path.join(path, 'PollutionData\\dbo.PUBLISH_POLLUTANTRELEASE.csv'), low_memory=False)
-        pr.to_pickle(os.path.join(path, 'PollutionData\\pr.pkl'))
+    if (os.path.isfile(os.path.join(path, 'PollutionData', 'pr.pkl')) is False) or force_rerun:
+        pr = pd.read_csv(os.path.join(path, 'PollutionData', 'dbo.PUBLISH_POLLUTANTRELEASE.csv'), low_memory=False)
+        pr.to_pickle(os.path.join(path, 'PollutionData', 'pr.pkl'))
 
     return None
 
@@ -222,19 +231,21 @@ def merge_PollutionData(path, force_rerun=False):
     None.
 
     """
-    if (os.path.isfile(os.path.join(path, 'PollutionData\\db.pkl')) is False) or force_rerun:
+    if (os.path.isfile(os.path.join(path, 'PollutionData', 'db.pkl')) is False) or force_rerun:
         try:
-            fr = pd.read_pickle(os.path.join(path, 'PollutionData\\fr.pkl'))
-            pr = pd.read_pickle(os.path.join(path, 'PollutionData\\pr.pkl'))
-            pratr = pd.read_pickle(os.path.join(path, 'PollutionData\\pratr.pkl'))
+            fr = pd.read_pickle(os.path.join(path, 'PollutionData', 'fr.pkl'))
+            pr = pd.read_pickle(os.path.join(path, 'PollutionData', 'pr.pkl'))
+            pratr = pd.read_pickle(os.path.join(path, 'PollutionData', 'pratr.pkl'))
         except FileNotFoundError:
             print('Error. Run function pickle_RawData')
-        # speed difference for variing merge-order?? Table length differs, merge smart enough to add multiple one row to multiple?
+        # speed difference for variing merge-order?? Table length differs,
+        # merge smart enough to add multiple one row to multiple?
         # problematic to merge by multiple coloum names?
         # Some data have no PostalCode, wrong fomrated postal code or not actual PostalCode
         db01 = pd.merge(fr, pratr, on=['PollutantReleaseAndTransferReportID', 'CountryName', 'CountryCode'])
-        db02 = pd.merge(db01, pr, on=['FacilityReportID', 'ConfidentialIndicator', 'ConfidentialityReasonCode', 'ConfidentialityReasonName'])
-        db02.to_pickle(os.path.join(path, 'PollutionData\\db.pkl'))
+        db02 = pd.merge(db01, pr, on=['FacilityReportID', 'ConfidentialIndicator', 'ConfidentialityReasonCode',
+                                      'ConfidentialityReasonName'])
+        db02.to_pickle(os.path.join(path, 'PollutionData', 'db.pkl'))
     return None
 
 
@@ -258,7 +269,8 @@ def generate_PollutionData_2(path):
     if os.path.isdir(path) is False:
         os.mkdir(path)
     if 'emipy_newdb.pkl' not in os.listdir(path):
-        url = 'https://gitlab-public.fz-juelich.de/s.morgenthaler/emipy/-/raw/master/additionaldata/emipy_newdb.pkl?inline=false'
+        url = ('https://gitlab-public.fz-juelich.de/network-science-group/emipy/'
+               + '-/raw/master/additionaldata/emipy_newdb.pkl?inline=false')
         urllib.request.urlretrieve(url, os.path.join(path, 'emipy_newdb.pkl'))
     if 'dbnew.pkl' not in os.listdir(path):
         data = pd.read_pickle(os.path.join(path, 'emipy_newdb.pkl'), compression='xz')
@@ -311,7 +323,8 @@ def get_RootPath():
 
     """
     config = configparser.ConfigParser()
-    config.read(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration\\configuration.ini'))
+    config.read(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration',
+                             'configuration.ini'))
     path = config['PATH']['path']
     return path
 
@@ -331,9 +344,13 @@ def change_RootPath(path):
 
     """
     config = configparser.ConfigParser()
-    config.read(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration\\configuration.ini'))
+    print(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration',
+                       'configuration.ini'))
+    config.read(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration',
+                             'configuration.ini'))
     config.set('PATH', 'path', path)
-    with open(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration\\configuration.ini'), 'w') as configfile:
+    with open(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration',
+                           'configuration.ini'), 'w') as configfile:
         config.write(configfile)
 
 
@@ -357,7 +374,8 @@ def init_emipy_project(path, resolution=10, force_rerun=False):
     """
     if path is None:
         print('A path to the root of the project is needed to initialize the project.')
-        return None
+        return
+
     change_RootPath(path)
     print('Root path successfully changed.')
     download_PollutionData(path=path)
@@ -365,7 +383,7 @@ def init_emipy_project(path, resolution=10, force_rerun=False):
     download_MapData(path=path, resolution=resolution)
     print('Map data successfully downloaded and extractet.')
     download_NACE_TransitionTables(path)
-    print('Transition tables succesfully downloaded.')
+    print('Transition tables successfully downloaded.')
     pickle_RawData(path=path, force_rerun=force_rerun)
     merge_PollutionData(path=path, force_rerun=force_rerun)
     print('Data merged and pickled.')
@@ -376,4 +394,5 @@ def init_emipy_project(path, resolution=10, force_rerun=False):
     if os.path.isdir(path) is False:
         os.mkdir(path)
     print('The initialisation process is completed.')
-    return None
+
+    return
